# Что это

Библиотека для работы с файлами и СУБД

# Установка через [`pip`](https://pypi.org/project/mg-file/)

```bash
pip install mg-file
```

# Технологии

| Технологии                                      | Описание                                                      |
|-------------------------------------------------|---------------------------------------------------------------|
| [Файлы](mg_file/file/README.md)                 | Работа с `txt`, `csv` , `json` , `pickl`                      |
| [Чистый SQL запросы](mg_file/sql_raw/README.md) | Синхронный / Асинхронный доступ к СУБД `PostgreSQL` , `MySql` |
| [SQL ORM](mg_file/sqllite_orm/README.md)        | `ORM` система                                                 |


